@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "bmp" "0.6.2"
+(define-package "bmp" "20251005.2032"
   "Version bumper for git projects."
   '((emacs "29"))
   :url "https://git.sr.ht/~lepisma/bmp"
-  :commit "63aeacf69a12aa8b47ae4d9e2d859e5d1c954012"
-  :revdesc "63aeacf69a12"
+  :commit "8f4fe653ee49860d764b789919bbd46a4a9d3768"
+  :revdesc "8f4fe653ee49"
   :authors '(("Abhinav Tushar" . "lepisma@fastmail.com"))
   :maintainers '(("Abhinav Tushar" . "lepisma@fastmail.com")))
